@@ -3,7 +3,7 @@
 See https://github.com/Vyxal/Vyxal/blob/fresh-beginnings/documents/specs/Structures.md
 """
 
-from typing import Optional, Union
+from typing import Union
 
 from vyxal.lexer import Token
 
@@ -89,12 +89,22 @@ class Lambda(Structure):
 class LambdaOp(Structure):
     """A lambda followed by a monad"""
 
-    def __init__(self, body: list[Structure], after: str):
+    def __init__(self, body: list[Structure], after: str, arity: int = 1):
         super().__init__(body, after)
-        self.lam = Lambda(1, body)
+        self.lam = Lambda(arity, body)
         self.after = after
 
 
+class LambdaMapDyadic(LambdaOp):
+    def __init__(self, body: list[Structure]):
+        super().__init__(body, after="M", arity=2)
+
+
+class LambdaMapTriadic(LambdaOp):
+    def __init__(self, body: list[Structure]):
+        super().__init__(body, after="M", arity=3)
+
+
 class LambdaMap(LambdaOp):
     def __init__(self, body: list[Structure]):
         super().__init__(body, after="M")
@@ -110,6 +120,16 @@ class LambdaFilter(LambdaOp):
         super().__init__(body, after="F")
 
 
+class LambdaFilterDyadic(LambdaOp):
+    def __init__(self, body: list[Structure]):
+        super().__init__(body, after="F", arity=2)
+
+
+class LambdaFilterTriadic(LambdaOp):
+    def __init__(self, body: list[Structure]):
+        super().__init__(body, after="F", arity=3)
+
+
 class LambdaSort(LambdaOp):
     def __init__(self, body: list[Structure]):
         super().__init__(body, after="ṡ")
